Text User Interface for
macrounchainedFocusGW.
The interface guide the user through a series of questions,
for fetching template Excel files for macrounchainedFocusGW
or picking an Excel file with parameter sets and starting
macrounchainedFocusGW.
1 |
See macrounchainedFocusGW.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.